From 04ee5ae0197b004e2fb59970359da39788868182 Mon Sep 17 00:00:00 2001
From: Miroslav Rezanina <mrezanin@redhat.com>
Date: Wed, 31 Jul 2013 08:05:46 +0200
Subject: pc: Add machine type "rhel6.3.0"

Message-id: <1375201922-6794-13-git-send-email-armbru@redhat.com>
Patchwork-id: 52826
O-Subject: [RHEL-7 PATCH v3 12/15] pc: Add machine type "rhel6.3.0"
Bugzilla: 983991
RH-Acked-by: Paolo Bonzini <pbonzini@redhat.com>
RH-Acked-by: Bandan Das <bsd@redhat.com>
RH-Acked-by: Miroslav Rezanina <mrezanin@redhat.com>

RHEL-6's non-upstream virtio-net-pci.x-__com_redhat_rhel620_compat
will be covered separately, if necessary (no BZ yet).

Signed-off-by: Markus Armbruster <armbru@redhat.com>

diff --git a/hw/i386/pc_piix.c b/hw/i386/pc_piix.c
index eaf3af1..dff2543 100644
--- a/hw/i386/pc_piix.c
+++ b/hw/i386/pc_piix.c
@@ -777,7 +777,7 @@ static QEMUMachine pc_machine_rhel700 = {
     DEFAULT_MACHINE_OPTIONS,
 };
 
-#define PC_RHEL6_2_COMPAT \
+#define PC_RHEL6_3_COMPAT \
     {\
         .driver   = "Conroe-" TYPE_X86_CPU,\
         .property = "model",\
@@ -909,7 +909,7 @@ static QEMUMachine pc_machine_rhel700 = {
         .value    = stringify(1),\
     }
 
-static void pc_init_rhel620(QEMUMachineInitArgs *args)
+static void pc_init_rhel630(QEMUMachineInitArgs *args)
 {
     has_pvpanic = false;
     disable_kvm_pv_eoi();
@@ -917,6 +917,26 @@ static void pc_init_rhel620(QEMUMachineInitArgs *args)
     pc_init_rhel700(args);
 }
 
+static QEMUMachine pc_machine_rhel630 = {
+    .name = "rhel6.3.0",
+    .desc = "RHEL 6.3.0 PC",
+    .init = pc_init_rhel630,
+    .max_cpus = 255,
+    .compat_props = (GlobalProperty[]) {
+        PC_RHEL6_3_COMPAT,
+        { /* end of list */ }
+    },
+    DEFAULT_MACHINE_OPTIONS,
+};
+
+#define PC_RHEL6_2_COMPAT \
+    PC_RHEL6_3_COMPAT
+
+static void pc_init_rhel620(QEMUMachineInitArgs *args)
+{
+    pc_init_rhel630(args);
+}
+
 static QEMUMachine pc_machine_rhel620 = {
     .name = "rhel6.2.0",
     .desc = "RHEL 6.2.0 PC",
@@ -1010,6 +1030,7 @@ static QEMUMachine pc_machine_rhel600 = {
 static void rhel_machine_init(void)
 {
     qemu_register_machine(&pc_machine_rhel700);
+    qemu_register_machine(&pc_machine_rhel630);
     qemu_register_machine(&pc_machine_rhel620);
     qemu_register_machine(&pc_machine_rhel610);
     qemu_register_machine(&pc_machine_rhel600);
